@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 """A set of utility functions to support outlier detection.
 """
-# Author: Yue Zhao <yuezhao@cs.toronto.edu>
+# Author: Yue Zhao <zhaoy@cmu.edu>
 # License: BSD 2 clause
 
 from __future__ import division
 from __future__ import print_function
 
 import numpy as np
+from numpy import percentile
 import numbers
 
 import sklearn
@@ -18,7 +19,6 @@ from sklearn.utils import column_or_1d
 from sklearn.utils import check_array
 from sklearn.utils import check_consistent_length
 
-from scipy.stats import scoreatpercentile
 from sklearn.utils import check_random_state
 from sklearn.utils.random import sample_without_replacement
 
@@ -163,7 +163,7 @@ def standardizer(X, X_t=None, keep_scalar=False):
         X_t = check_array(X_t)
         if X.shape[1] != X_t.shape[1]:
             raise ValueError(
-                "The number of input data feature should be consistnt"
+                "The number of input data feature should be consistent"
                 "X has {0} features and X_t has {1} features.".format(
                     X.shape[1], X_t.shape[1]))
         if keep_scalar:
@@ -195,7 +195,7 @@ def score_to_label(pred_scores, outliers_fraction=0.1):
     pred_scores = column_or_1d(pred_scores)
     check_parameter(outliers_fraction, 0, 1)
 
-    threshold = scoreatpercentile(pred_scores, 100 * (1 - outliers_fraction))
+    threshold = percentile(pred_scores, 100 * (1 - outliers_fraction))
     pred_labels = (pred_scores > threshold).astype('int')
     return pred_labels
 
@@ -254,10 +254,10 @@ def get_label_n(y, y_pred, n=None):
     Examples
     --------
     >>> from pyod.utils.utility import get_label_n
-    >>> y = [0, 1, 1, 0, 0, 0]
+    >>> y = [0, 1, 1, 0, 0]
     >>> y_pred = [0.1, 0.5, 0.3, 0.2, 0.7]
     >>> get_label_n(y, y_pred)
-    >>> [0, 1, 0, 0, 1]
+    array([0, 1, 0, 0, 1])
 
     """
 
@@ -274,7 +274,7 @@ def get_label_n(y, y_pred, n=None):
     else:
         outliers_fraction = np.count_nonzero(y) / y_len
 
-    threshold = scoreatpercentile(y_pred, 100 * (1 - outliers_fraction))
+    threshold = percentile(y_pred, 100 * (1 - outliers_fraction))
     y_pred = (y_pred > threshold).astype('int')
 
     return y_pred
@@ -349,9 +349,9 @@ def invert_order(scores, method='multiplication'):
     --------
     >>> scores1 = [0.1, 0.3, 0.5, 0.7, 0.2, 0.1]
     >>> invert_order(scores1)
-    >>> array[-0.1, -0.3, -0.5, -0.7, -0.2, -0.1]
+    array([-0.1, -0.3, -0.5, -0.7, -0.2, -0.1])
     >>> invert_order(scores1, method='subtraction')
-    >>> array[0.6, 0.4, 0.2, 0, 0.5, 0.6]
+    array([0.6, 0.4, 0.2, 0. , 0.5, 0.6])
     """
 
     scores = column_or_1d(scores)
@@ -363,19 +363,37 @@ def invert_order(scores, method='multiplication'):
         return (scores.max() - scores).ravel()
 
 
-def _sklearn_version_20():
+def _get_sklearn_version():  # pragma: no cover
+    """ Utility function to decide the version of sklearn.
+    PyOD will result in different behaviors with different sklearn version
+
+    Returns
+    -------
+    sk_learn version : int
+
+    """
+
+    sklearn_version = str(sklearn.__version__)
+    if int(sklearn_version.split(".")[1]) < 19 or int(
+            sklearn_version.split(".")[1]) > 23:
+        raise ValueError("Sklearn version error")
+
+    return int(sklearn_version.split(".")[1])
+
+
+def _sklearn_version_21():  # pragma: no cover
     """ Utility function to decide the version of sklearn
-    In sklearn 20.0, LOF is changed. Specifically, _decision_function
+    In sklearn 21.0, LOF is changed. Specifically, _decision_function
     is replaced by _score_samples
 
     Returns
     -------
-    sklearn_20_flag : bool
-        True if sklearn.__version__ is newer than 0.20.0
+    sklearn_21_flag : bool
+        True if sklearn.__version__ is newer than 0.21.0
 
     """
     sklearn_version = str(sklearn.__version__)
-    if int(sklearn_version.split(".")[1]) > 19:
+    if int(sklearn_version.split(".")[1]) > 20:
         return True
     else:
         return False
